@@ -14,6 +14,8 @@
 # 2015-12-21 Paco - neue Datenbankversion 3 (Reihungsocde für Area und Product)
 #                 - neue Datenbankversion 4
 #                   * interne Sicht fuer Gruppen einstellbar
+# 2016-10-23 Paco PL-Kunde mit ID 5 ist immer noch nicht korrekt
+#                 im Datenmodell --> bereinigt
 ######################################################################
 ####  Variables that should be adapted if necessary
 ####------------------------------------------------------------------
@@ -278,6 +280,17 @@ function check4NecessaryDBUpdates() {
             }
             $dbExistingVersion = 6;
         }
+        
+        if ($dbExistingVersion == 6) {
+            logIntoFile("Updating DB-Model: 6 --> 7");
+
+            $sQuery = "Insert into OPLIST_GROUP (OPGID, OPGTEXT, ACTIVE, INTERNAL, CLIENT) Values (5, 'PL-Kunde', 1, 0, 1)";
+            debugIntoFile("Update-Select1=".$sQuery);
+            getRessource($sQuery);
+            logSQLError();
+
+            $dbExistingVersion = 7;
+        }
 
         # update version
         $sQuery = "UPDATE OPLIST_VERSION SET OPVVERSION=".$databaseMinVersion.", OPVDESC='".$myVersion.".".$SVNRevision."' WHERE OPVID = 1";
